## Progress Ledger

### Question

Recall we are working to answer the following question:

{question}

### Team

We have assembled the following team:

{team_description}

### Progress Report

To make progress on answering the question, please answer the following questions, including necessary reasoning:

- Is the question fully answered? (True if complete, or False if the original request has yet to be SUCCESSFULLY and FULLY addressed)
- Are we in a loop where we are repeating the same requests and / or getting the same responses as before? 
  Loops can span multiple turns, and can include repeated actions like scrolling up or down more than a handful of times.
- Are we making forward progress?
    - True if just starting, or recent messages are adding value.
    - False if recent messages show evidence of being stuck in a loop or if there is evidence of significant barriers to success such as the inability to read from a required file
- Who should speak next? (select from: {names})
- What instruction or question would you give this team member? (Phrase as if speaking directly to them, and include any specific information they may need)
